@@ -17,20 +17,6 @@ class JobArchiveView(BaseView):
         yield "/branches/{branch}/{tag}/{job}.tar"
         yield "/~{user}/branches/{branch}/{tag}/{job}.tar"
 
-    def _get_job(self):
-        match = self.request.match_info
-        if match["tag"] in ("latest", "stable") and self.request.method != "GET":
-            raise web.HTTPMethodNotAllowed(self.request.method, ["GET"])
-        try:
-            return (
-                self.repo()
-                .get_branch(match["branch"])
-                .get_tag(match["tag"])
-                .get_job(match["job"])
-            )
-        except FileNotFoundError as e:
-            raise web.HTTPNotFound() from e
-
     def _digests(self, job):
         digests = {}
         for fmt in job.get_formats():
@@ -40,7 +26,7 @@ class JobArchiveView(BaseView):
         return digests
 
     async def get(self):
-        job = self._get_job()
+        job = _get_job(self.repo(), self.request)
         url = job.url().rstrip("/") + ".tar"
         if url != self.request.path:
             raise web.HTTPFound(url)
@@ -48,7 +34,7 @@ class JobArchiveView(BaseView):
 
 
 # --------------------------------------------------------------------------------------
-class JobView(JobArchiveView):
+class JobView(BaseView):
     @classmethod
     def urls(cls):
         yield "/branches/{branch}/{tag}/{job}"
@@ -60,7 +46,7 @@ class JobView(JobArchiveView):
         """
         Get info about a job including metadata and artifact formats.
         """
-        job = self._get_job()
+        job = _get_job(self.repo(), self.request)
         if not job.exists():
             raise web.HTTPNotFound()
         if job.url() != self.request.path:
@@ -97,7 +83,7 @@ class JobView(JobArchiveView):
         return web.json_response(data)
 
     async def put(self):
-        job = self._get_job()
+        job = _get_job(self.repo(), self.request)
         try:
             data = (await self.json_body())["job"]
             internal = data.get("internal")
@@ -132,7 +118,8 @@ class JobView(JobArchiveView):
         except (TypeError, KeyError) as e:
             raise web.HTTPBadRequest(reason="Invalid parameters") from e
         try:
-            self._get_job().add_metadata(data)
+            job = _get_job(self.repo(), self.request)
+            job.add_metadata(data)
         except FileExistsError as e:
             raise web.HTTPBadRequest(reason=str(e)) from e
         return web.Response()
@@ -143,7 +130,7 @@ class JobView(JobArchiveView):
         """
         loop = asyncio.get_running_loop()
         try:
-            job = self._get_job()
+            job = _get_job(self.repo(), self.request)
             await loop.run_in_executor(None, job.delete)
             self.repo().schedule_cleanup_orphans()
         except FileNotFoundError as e:
@@ -151,3 +138,18 @@ class JobView(JobArchiveView):
         except OSError as e:
             raise web.HTTPBadRequest(reason=str(e)) from e
         return web.Response()
+
+
+# --------------------------------------------------------------------------------------
+def _get_job(repo, request):
+    match_info = request.match_info
+    if match_info["tag"] in ("latest", "stable") and request.method != "GET":
+        raise web.HTTPMethodNotAllowed(request.method, ["GET"])
+    try:
+        return (
+            repo.get_branch(match_info["branch"])
+            .get_tag(match_info["tag"])
+            .get_job(match_info["job"])
+        )
+    except FileNotFoundError as e:
+        raise web.HTTPNotFound() from e
