@@ -23,7 +23,7 @@ def temp_dir():
 @pytest.fixture(scope="module")
 def dlrepo_server(request, temp_dir):  # pylint: disable=redefined-outer-name
     data_dir = pathlib.Path(request.fspath).parent / request.module.__name__
-    for d in ("branches", "products", "users", ".blobs"):
+    for d in ("branches", "products", "users"):
         folder = data_dir / d
         if folder.is_dir():
             shutil.copytree(folder, temp_dir / d)
@@ -44,7 +44,16 @@ def dlrepo_server(request, temp_dir):  # pylint: disable=redefined-outer-name
     if auth.is_file():
         env["DLREPO_AUTH_FILE"] = str(auth)
     else:
-        env["DLREPO_AUTH_DISABLED"] = "1"
+        headers = data_dir / "headers"
+        if headers.is_dir():
+            for h in headers.iterdir():
+                env[h.name] = h.read_text("utf-8").strip()
+        else:
+            env["DLREPO_AUTH_DISABLED"] = "1"
+    settings = data_dir / "settings"
+    if settings.is_dir():
+        for s in settings.iterdir():
+            env[s.name] = s.read_text("utf-8").strip()
     post_process = data_dir / "post-process.sh"
     if post_process.is_file():
         env["DLREPO_POST_PROCESS_CMD"] = str(post_process)
